@@ -4,9 +4,11 @@ from typing import Optional, List, Dict, Any
 def aggregation_chart(
     groupby: List[Dict[str, Any]],
     metric: List[Dict[str, Any]],
+    chart_type: str = "column",
     title: Optional[str] = None,
     page_size: int = 20,
     show_frequencies: bool = False,
+    sentiment_field: str = "",
     sort_direction: str = "desc",
 ):
     """
@@ -26,7 +28,7 @@ def aggregation_chart(
         },
     ]
     """
-    assert sort_direction in {"Descending", "Ascending"}
+    assert sort_direction in {"desc", "asc"}
 
     for query in groupby:
         query["aggType"] = "groupby"
@@ -43,7 +45,7 @@ def aggregation_chart(
                     "attrs": {
                         "uid": "",
                         "title": title,
-                        "chartType": "column",
+                        "chartType": chart_type,
                         "filters": [],
                         "xAxis": {
                             "fields": [],
@@ -61,7 +63,7 @@ def aggregation_chart(
                             "interval": "monthly",
                         },
                         "sentiment": {
-                            "field": "",
+                            "field": sentiment_field,
                             "mode": "overview",
                             "interval": "monthly",
                         },
